pywws.conversions — pywws 12.12_e27456b documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws 12.12_e27456b documentation »
- Python programs and modules »

# pywws.conversions

conversions.py - a set of functions to convert pywws native units (Centigrade, mm, m/s, hPa) to other popular units

Functions

`pressure_inhg`(hPa) | Convert pressure from hectopascals/millibar to inches of mercury
`rain_inch`(mm) | Convert rainfall from millimetres to inches
`temp_f`(c) | Convert temperature from Celsius to Fahrenheit
`wind_bft`(ms) | Convert wind from metres per second to Beaufort scale
`wind_kmph`(ms) | Convert wind from metres per second to kilometres per hour
`wind_kn`(ms) | Convert wind from metres per second to knots
`wind_mph`(ms) | Convert wind from metres per second to miles per hour

`pywws.conversions.` `illuminance_wm2`(lux)

  Approximate conversion of illuminance in lux to solar radiation in W/m2

`pywws.conversions.` `pressure_inhg`(hPa)

  Convert pressure from hectopascals/millibar to inches of mercury

`pywws.conversions.` `rain_inch`(mm)

  Convert rainfall from millimetres to inches

`pywws.conversions.` `temp_f`(c)

  Convert temperature from Celsius to Fahrenheit

`pywws.conversions.` `winddir_degrees`(pts)

  Convert wind direction from 0..15 to degrees

`pywws.conversions.` `winddir_text`(pts)

  Convert wind direction from 0..15 to compass point text

`pywws.conversions.` `wind_kmph`(ms)

  Convert wind from metres per second to kilometres per hour

`pywws.conversions.` `wind_mph`(ms)

  Convert wind from metres per second to miles per hour

`pywws.conversions.` `wind_kn`(ms)

  Convert wind from metres per second to knots

`pywws.conversions.` `wind_bft`(ms)

  Convert wind from metres per second to Beaufort scale

`pywws.conversions.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws 12.12_e27456b documentation »
- Python programs and modules »